"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var LoggerModule_1, LoggerCoreModule_1;
Object.defineProperty(exports, "__esModule", { value: true });
"use strict";
const common_1 = require("@nestjs/common");
const pino_http_1 = __importDefault(require("pino-http"));
const pino_1 = __importDefault(require("pino"));
const express_ctx_1 = require("express-ctx");
const LOGGER_KEY = "logger";
const OPTIONS_PROVIDER_TOKEN = "pino-options";
let Logger = class Logger {
    constructor(options) {
        if (Array.isArray(options)) {
            this.outOfContext = pino_1.default(...options);
        }
        else if (isPassedLogger(options)) {
            this.outOfContext = options.logger;
        }
        else {
            this.outOfContext = pino_1.default(options || undefined);
        }
    }
    verbose(message, context, ...args) {
        if (context) {
            this.logger.trace({ context }, message, ...args);
        }
        else {
            this.logger.trace(message);
        }
    }
    debug(message, context, ...args) {
        if (context) {
            this.logger.debug({ context }, message, ...args);
        }
        else {
            this.logger.debug(message);
        }
    }
    log(message, context, ...args) {
        if (context) {
            this.logger.info({ context }, message, ...args);
        }
        else {
            this.logger.info(message);
        }
    }
    warn(message, context, ...args) {
        if (context) {
            this.logger.warn({ context }, message, ...args);
        }
        else {
            this.logger.warn(message);
        }
    }
    error(message, trace, context, ...args) {
        if (context) {
            this.logger.error({ context, trace }, message, ...args);
        }
        else if (trace) {
            this.logger.error({ trace }, message);
        }
        else {
            this.logger.error(message);
        }
    }
    get logger() {
        return express_ctx_1.getValue(LOGGER_KEY) || this.outOfContext;
    }
};
Logger = __decorate([
    common_1.Injectable(),
    __param(0, common_1.Inject(OPTIONS_PROVIDER_TOKEN)),
    __metadata("design:paramtypes", [Object])
], Logger);
exports.Logger = Logger;
let LoggerModule = LoggerModule_1 = class LoggerModule {
    static forRoot(opts, stream) {
        return {
            module: LoggerModule_1,
            imports: [
                LoggerCoreModule.forRoot(stream ? [opts, stream] : opts)
            ]
        };
    }
    static forRootAsync(options) {
        return {
            module: LoggerModule_1,
            imports: [LoggerCoreModule.forRootAsync(options)]
        };
    }
};
LoggerModule = LoggerModule_1 = __decorate([
    common_1.Module({})
], LoggerModule);
exports.LoggerModule = LoggerModule;
let LoggerCoreModule = LoggerCoreModule_1 = class LoggerCoreModule {
    constructor(options) {
        this.options = options;
    }
    static forRoot(options) {
        const optionsProvider = {
            provide: OPTIONS_PROVIDER_TOKEN,
            useValue: options || null
        };
        return {
            module: LoggerCoreModule_1,
            providers: [Logger, optionsProvider],
            exports: [Logger]
        };
    }
    static forRootAsync(options) {
        const optionsProvider = {
            provide: OPTIONS_PROVIDER_TOKEN,
            useFactory: options.useFactory,
            inject: options.inject
        };
        return {
            module: LoggerCoreModule_1,
            imports: options.imports,
            providers: options.providers
                ? [Logger, optionsProvider, ...options.providers]
                : [Logger, optionsProvider],
            exports: [Logger]
        };
    }
    configure(consumer) {
        consumer
            .apply(...createLoggerMiddlewares(this.options))
            .forRoutes({ path: "*", method: common_1.RequestMethod.ALL });
    }
};
LoggerCoreModule = LoggerCoreModule_1 = __decorate([
    common_1.Global(),
    common_1.Module({ providers: [Logger], exports: [Logger] }),
    __param(0, common_1.Inject(OPTIONS_PROVIDER_TOKEN)),
    __metadata("design:paramtypes", [Object])
], LoggerCoreModule);
function isPassedLogger(params) {
    return !!params && "logger" in params;
}
function createLoggerMiddlewares(params) {
    const middleware = Array.isArray(params)
        ? pino_http_1.default(...params)
        : pino_http_1.default(params || undefined);
    return [express_ctx_1.middleware, middleware, bindLoggerMiddleware];
}
function bindLoggerMiddleware(req, res, next) {
    express_ctx_1.setValue(LOGGER_KEY, req.log);
    next();
}
//# sourceMappingURL=index.js.map